const path = require('path')
const {
	override,
	addDecoratorsLegacy,
	addWebpackAlias,
} = require('customize-cra')

//修改 环境变量
process.env.PORT = 9000
process.env.BROWSER = 'none' //devServer不自动打开浏览器
process.env.GENERATE_SOURCEMAP = false // 生产环境是否打包 Source Map
process.env.PUBLIC_URL = './'

const removePlugin = (plugins, name) => {
	const list = plugins.filter((it) => !(it.constructor && it.constructor.name && name === it.constructor.name))
	if (list.length === plugins.length) {
		throw new Error(`Can not found plugin: ${name}.`)
	}
	return list
}

const Config = (config, env) => {
	config.externals = {
		"KRtcCilent": "KRtcCilent"
	}
	config.resolve.plugins = removePlugin(config.resolve.plugins, 'ModuleScopePlugin')
	return config
}

module.exports = {
	webpack: override(
		// 配置路径别名
		addWebpackAlias({ '@': path.join(__dirname, 'src') }),
		// 对Decorators支持
		addDecoratorsLegacy(),

		Config,
	),

	devServer: (configFunction) => (proxy, allowedHost) => {
		let config = configFunction(proxy, allowedHost)

		config.proxy = {
			'/api': {
				target: 'https://dev.kedacom.com/',
				secure: false, //
				changeOrigin: true,
				// rejectUnauthorized: false,
				pathRewrite: {
					'^/api': '/api',
				},
			},
		}

		return config
	},

	jest: (config) => {
		config.moduleNameMapper = {
			...config.moduleNameMapper,
			'^@/(.*)$': '<rootDir>/src/$1',
		}
		return config
	},

	paths: (paths, env) => {
		paths.appBuild = path.resolve('dist')
		return paths
	},
}
