import { Suspense, lazy, useState, useEffect } from 'react'
import { Spin } from 'antd';
import { CenterStyle } from './style';
import { HashRouter as Router, Route, Switch, Redirect } from 'react-router-dom'
import kRtcClient from 'KRtcCilent'
import Store from './store/index'
import UrlParse from 'url-parse';


function App() {
	const [hasLogin,setHasLogin] = useState(false);
	const [roomId,setRoomId]= useState("")
	/**sdk初始化完成标志 */
	const [flag,setFlag]=useState(false);
	useEffect( () => {
		const KrtcClientIds = kRtcClient.getClientIds();
    	console.log("KrtcClientIds",KrtcClientIds);
		if(KrtcClientIds.length > 0){
			initSdk(KrtcClientIds)
		}else{
			setHasLogin(false)
			setFlag(true)
		}
	},[])
	/**初始化sdk */
	const initSdk = async (KrtcClientIds)=>{
		  const krtcClient = new kRtcClient({clientId: KrtcClientIds[0]});
		  krtcClient.init({
			hostname:window.location.host,
			autoSubAllVideoStream:true,
			success: function() {
				const isLogin = JSON.parse(window.atob(JSON.parse(localStorage.getItem(krtcClient._singleSdk.getClientId()))["kAuthorization"]))["ssoToken"] || null;
				console.log("ssoToken -----", isLogin)
				/**sdk已登录且aps已登录 */
				if(isLogin){
					window.krtcClient = krtcClient
					console.log('------------------window.krtcClient---------------------')
					setHasLogin(true);
					const urlParser = new UrlParse(window.location.href, true);
					let roomId = urlParser.query.roomId || window.krtcClient.getRoomId();
					setRoomId(roomId)
					setFlag(true)
				}else{
					setHasLogin(false)
					setFlag(true)
				}
			},
			error: function() {
				
				setHasLogin(false)
				setFlag(true)
			}
		});
	}
	return (
		flag ?
		<Router >
			<Suspense fallback={<CenterStyle><Spin /></CenterStyle>}>
				<Switch>
					<Route exact path="/" render={() => {
							if(hasLogin){
								if(roomId){
									return <Redirect to="/list/:roomId" push />
								}
								return <Redirect to="/list" push />
							}else{
								return <Redirect to="/login" push />
							}
						
						
					}} />
					<Route path="/login" component={lazy(() => import('@/pages/Login'))} />
					<Route path="/list/:roomId" component={lazy(() => import('@/pages/Room'))} />
					<Route path="/list" component={lazy(() => import('@/pages/List'))} />
					
					<Route component={lazy(() => import('@/pages/NotFound'))} />
				</Switch>
			</Suspense>
		</Router>:(<CenterStyle><Spin /></CenterStyle>)
		
	);
}

export default App;
