import { useState,useEffect } from "react"
import { Modal, Form, Input, Button, Space, message, notification, Card, Radio } from 'antd';
import { useHistory } from "react-router-dom";
import { CloudServerOutlined, UserOutlined, HomeOutlined, SettingOutlined } from '@ant-design/icons';
import { WrapStyle, GlobalStyle } from './style';
import Store from '../../store'
import fetchAxios from '@/api/axios';
import AccessToken from '../../utils/AccessToken'
import KRtcCilent from 'KRtcCilent'

const OAUTH_KEY = 'krtctest'
const OAUTH_SECRET = 'krtctest'

export default function Login() {
	const history = useHistory();
	const [isModalVisible, setIsModalVisible] = useState(false);
	const [oauthVal, setOauthVal] = useState({ oauth_consumer_key: OAUTH_KEY, oauth_consumer_secret: OAUTH_SECRET })
	const [inputOauthVal, setInputOauthVal] = useState(oauthVal);
	const [user] = useState({hostname: window.location.hostname, userId: '', nickname: '', roomId: ''})
	const [loginType, setLoginType] = useState(true);
	const [form] = Form.useForm();

	const handleChange = (key) => (e) => {
		const { value } = e.target;
		setInputOauthVal(val => ({ ...val, [key]: value }))
	}

	const handleOk = () => {
		setOauthVal(inputOauthVal)
		Store.setAppToken(inputOauthVal)
		setIsModalVisible(false);
	};

	const handleCancel = () => {
		setInputOauthVal(oauthVal)
		setIsModalVisible(false);
	};

	//页面初始化
	useEffect(() => {
		let userInfo = Store.user;
		if(userInfo){
			form.setFieldsValue(userInfo)
		}
		let oauthVal = Store.appToken;
		if(oauthVal){
			setOauthVal(oauthVal);
			setInputOauthVal(oauthVal)
		}
		//如果已登录
		if(window.krtcClient){
			const isLogin = JSON.parse(window.atob(JSON.parse(localStorage.getItem(window.krtcClient && window.krtcClient._singleSdk.getClientId()))["kAuthorization"]))["ssoToken"] || null;
			if (Store.user && isLogin) {
			  history.push("/list");
			}
		}
	}, [])
	const doInit = (values) =>{
		// 若昵称为空则设置为UserID
		if(!values.nickname) {
			values.nickname = values.userId;
		}

		window.krtcClient =  new KRtcCilent();
		doLogin(values)
		// window.krtcClient.init({
		// 	// protocol: "http",
		// 	hostname: values.hostname,
		// 	success: function() {
		// 		doLogin(values)
		// 	},
		// 	error: function() {
		// 		doLogin(values)
		// 	}
		// });
	}
	//登陆
	const doLogin = (values) => {
		const appToken = new AccessToken(oauthVal.oauth_consumer_key, oauthVal.oauth_consumer_secret).build(values.userId, 1000 * 60)
		console.log('================doLogin======================')
		const params = {
			userId: values.userId,
			appToken: appToken,
			autoSubAllVideoStream: true,
			autoPubLocalStream: true,
			nickname: values.nickname,
			hostname: values.hostname,
			success: function() {
				// SDK登录成功则保存用户登录信息
				Store.setUser(values);

				setTimeout(() => {
					onFinish(values, appToken)
				}, 1000)
			},
			error: function(errModal) {
				notification.error({
					message: '操作提示',
					description: '登录失败'
				})
			}
		}
		console.log('-----------params-----------', params)
		window.krtcClient.krtcLogin(params)
	}
	const onFinish = async (values,appToken) => {
		console.log('Received values of form: ', values);
		const resToken = await fetchAxios({
			url: '/system/token',
			method: 'post',
			data: oauthVal
		})
		if(resToken.data && resToken.data.success){
			const { account_token } = resToken.data
			Store.setAccountToken(account_token)
			const resUser = await fetchAxios({
				url: '/system/login',
				method: 'post',
				data: {
					account_token,
					username: values.userId,
					password: appToken,
				}
			})
			if(resUser.data && resUser.data.success) {
				history.push("/list");
			}else{
				message.error(`登录失败`);
			}	
		}else{
			message.error('token 获取失败');
		}

	};

	const changeLoginType = (key) => {
		setLoginType(key == 'loginTab');
	}

	const tabList = [
		{
			key: 'loginTab',
			tab: '登录进入',
		},
		{
			key: 'joinTab',
			tab: '快速入会',
		},
	];
	return <WrapStyle>
		<GlobalStyle />
		<Card title={<div className="title">科达KRTC快速对接示例</div>}
			tabList={tabList}
			onTabChange={key => {
				changeLoginType(key);
			}}
		 	bordered={false} style={{ width: 400, height: 420 }}>
			<Form
				name="form_login"
				initialValues={user}
				onFinish={doInit}
				form={form}
			>
				<Form.Item
					name="hostname"
					rules={[
						{
							required: true,
							message: '请输入连接服务器IP地址或域名!',
						},
					]}
				>
					<Input size="large" placeholder="连接服务器IP地址或域名" prefix={<CloudServerOutlined />} />
				</Form.Item>
				<Form.Item
					name="userId"
					rules={[
						{
							required: true,
							message: '请输入用户ID!',
						},
					]}
				>
					<Input size="large" placeholder="用户ID" prefix={<UserOutlined />} />
				</Form.Item>
				<Form.Item name="nickname" hidden={true}>
					<Input size="large" placeholder="昵称" prefix={<UserOutlined />} />
				</Form.Item>
				<Form.Item
					name="roomId"
					hidden={loginType}
					rules={[
						{
							required: !loginType,
							message: '请输入用户ID!',
						},
					]}
				>
					<Input size="large" placeholder="房间ID" prefix={<HomeOutlined />} />
				</Form.Item>
				<Form.Item>
					<Button size="large" htmlType="submit" type="primary" block>{loginType ? '登录' : '进入房间'}</Button>
				</Form.Item>
			</Form>
		</Card>
		<div className="setting" onClick={() => setIsModalVisible(true)}>
			<SettingOutlined />
		</div>

		<Modal title="认证信息" visible={isModalVisible} onOk={handleOk} onCancel={handleCancel} okText="确认" cancelText="取消">
			<Space direction="vertical" style={{ width: '100%' }}>
				<Input size="large" placeholder="oauth_consumer_key" value={inputOauthVal.oauth_consumer_key} onChange={handleChange('oauth_consumer_key')} />
				<Input size="large" placeholder="oauth_consumer_secret" value={inputOauthVal.oauth_consumer_secret} onChange={handleChange('oauth_consumer_secret')} />
			</Space>
		</Modal>
	</WrapStyle>
}
